Learn R Programming

EMMIXuskew (version 0.11-6)

EMMIXuskew-package: Finite mixture of unrestricted multivariate skew t distributions

Description

Theis package implements an EM algorithm for fitting mixtures of unrestricted multivariate skew t (FM-uMST) distributions. Functions for random sample generation, discriminant analysis, and visualisation (in 2D and 3D) is also provided.

Arguments

Details

Package:
EMMIXuskew
Type:
Package
Version:
0.11-6
Date:
2014-07-31
Licence:
GPL
LazyLoad:
yes

References

Lee S, McLachlan G (2011). On the fitting of mixtures of multivariate skew t-distributions via the EM algorithm. arXiv:1109.4706 [stat.ME]

Lee, S. and McLachlan, G.J. (2014) Finite mixtures of multivariate skew t-distributions: some recent and new results. Statistics and Computing, 24, 181-202. Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for fitting mixtures of multivariate skew t-distributions via the EM algorithm. Journal of Statistical Software, 55(12), 1-22. URL http://www.jstatsoft.org/v55/i12/.

See Also

fmmst, dfmmst, rfmmst, fmmst.contour.3d