Learn R Programming

EMMIXuskew (version 0.11-6)

Lympho: T-cell Phosphorylation dataset

Description

A subset of the T-cell phosphorylation dataset. The original data contain measurements of blood samples stained with four antibodies, CD4, CD45RA, SLP76 and ZAP70. Measurements from each subject were taken before and after anti-CD3 stimulation. This is a subset of the pre-stimulation data from one subject.

Usage

data(Lympho)

Arguments

Format

A data frame with 33399 observations (rows) on the following 2 variables (columns).
SLP76
marker 1
ZAP70
marker 2

References

Maier LM, Anderson DE, De Jager PL, Wicker L, Hafler DA (2007). Allelic variant in CTLA4 alters T cell phosphorylation patterns. Proceedings of the National Academy of Sciences of the United States of America, 104, 18607-18612.

Examples

Run this code
data(Lympho)
plot(Lympho, main="Lymphoma dataset")
smoothScatter(Lympho, nrpoints=Inf)

Run the code above in your browser using DataLab