Learn R Programming

EMMIXuskew (version 0.11-6)

delta.test: Testing for the significance of the skewness parameter in a FM-MST model

Description

Perform a likelihood ratio for the significance of the skewness parameter delta in a multivariate skew t-mixture model.

Usage

delta.test(stmodel=NULL, tmodel=NULL, stloglik, tloglik, r)

Arguments

stmodel
a list containing the parameters of the FM-MST model, including mu, sigma, delta, dof and pro. This is usually an output from a fmmst run.
tmodel
a list containing the parameters of the FM-MT model, including mu, sigma, dof and pro. This is usually an output from a fmmt run.
stloglik
a scalar specifying the log likelihood value of the skew t-mixture model
tloglik
a scalar specifying the log likelihood value of the t-mixture model
r
a scalar specifying the difference in the number of parameters between FM-MST and FM-MT model

Value

returns the P-value of the test

Details

A likelihood ratio test for hypotheses:

H0: delta = 0 (for all components in the mixture model)

H1: delta different from 0 (for at least one component in the mixture)

The test statistics is LR = -2 (L1 - L2), which follows a chi-sqaured distribution with r degrees of freedom under H0. r is the difference between the number of parameters in H0 and H1. See references for further details.

References

Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for fitting mixtures of multivariate skew t-distributions via the EM algorithm. Journal of Statistical Software, 55(12), 1-22. URL http://www.jstatsoft.org/v55/i12/.

See Also

fmmt, fmmst

Examples

Run this code
delta.test(stloglik=-1343.541, tloglik=-1353.842, r=4)

Run the code above in your browser using DataLab