Learn R Programming

EMMIXuskew (version 0.11-6)

dfmmst: Multivariate skew t distribution

Description

The probability density function for the unrestricted multivariate skew t (MST) distribution and finite mixture of MSN and MST distributions

Usage

dfmmst(dat, mu = NULL, sigma = NULL, delta = NULL, dof = NULL, pro = NULL, 
    known = NULL, tmethod=1)               
dmst(dat, mu = NULL, sigma = NULL, delta = NULL, dof = 1, known = NULL, tmethod=1)

Arguments

dat
the data matrix giving the coordinates of the point(s) where the density is evaluated. This is either a vector of length p or a matrix with p columns.
mu
for dmst, this is a numeric vector of length p representing the location parameter; for dfmmst, this is list of g numeric matrices each having p rows and 1 column cont
sigma
for dmst, this is a numeric positive definite matrix with dimension (p,p) representing the scale parameter; for dfmmst, this is list of g numeric matrices containing the scale parameter for each com
delta
for dmst, this is a numeric vector of length p representing the skewness parameter; for dfmmst, this is list of g numeric matrices each having p rows and 1 column cont
dof
for dmst, this is a positive integer specifying the degrees of freedom; for dfmmst, this is numeric vector of length g representing the degrees of freedom for each component.
pro
the mixing proportions; fordmst, this is equal to 1; for dfmmst, this is vector of length of g specifying the mixing proportions for each component.
known
a list containing the parameters of the model. If specified, it overwrites the values of mu, sigma, delta, dof and pro.
tmethod
(optional) an integer indicating which method to use when computing t distribution function values. See pmt for details.

Value

  • dmst and dfmmst returns a numeric vector of density values

Details

The function dmst computes the density value of a specified unrestricted multivariate skew t (MST) distribution. If any model parameters are not specified, their default values are used: mu and delta are zero vectors, sigma is the identity matrix, and dof is 1. The function dfmmst computes the density value for a specified mixture of MST distribution. Note that dfmmst expects at least dof is specified. Other missing parameters will take the default value described above. When g=1, dfmmst passes the call to dmst. Model parameters can be passed to dmst and dfmmst through the argument known or listed as individual arguments. If both methods of input were used, the parameters specified in known will be used.

References

Sahu S, Dey D, Branco M (2003). A New Class of Multivariate Skew Distributions with Applications to Bayesian Regression Models. The Canadian Journal of Statistics, 31, 129-150. Lee S, McLachlan G (2011). On the fitting of mixtures of multivariate skew t-distributions via the EM algorithm. arXiv:1109.4706 [stat.ME] Lee, S. and McLachlan, G.J. (2014) Finite mixtures of multivariate skew t-distributions: some recent and new results. Statistics and Computing, 24, 181-202.

See Also

rmst, rfmmst

Examples

Run this code
dmst(c(1,2), mu=c(1,5), sigma=diag(2), delta=c(-3,1), dof=4)
obj <- list()
obj$mu <- list(c(17,19), c(5,22), c(6,10))
obj$sigma <- list(diag(2), matrix(c(2,0,0,1),2), matrix(c(3,7,7,24),2))
obj$delta <- list(c(3,1.5), c(5,10), c(2,0))
obj$dof <- c(1, 2, 3)
obj$pro <- c(0.25, 0.25, 0.5)     
dfmmst(matrix(c(1,2,5,6,2,4),3,2), obj$mu, obj$sigma, obj$delta, 
    obj$dof, obj$pro)
dfmmst(c(1,2), known=obj)

Run the code above in your browser using DataLab