fmmst(g = 1, dat, initial = NULL, known = NULL, itmax = 100, eps = 1e-03, clust=NULL, nkmeans=20, print = T, tmethod=1)
"summary"(object, ...)
"print"(x, ...)"fmmst", i.e. a fitted model.
p or a matrix with p columns.
NULL.
NULL.
100.
1e-6.
nrow(dat) containing the
initial labels for each data point in dat. The default is NULL,
indicating no initial clustering is known.
20.
TRUE, output for each iteration will be printed out.
if FALSE, no output is printed. The default is TRUE. See the 'Details' section.
pmt for details.
g numeric matrices containing the location parameter for each component.
g numeric matrices containing the scale parameter for each component.
g numeric matrices containing the skewness parameter for each component.
g representing the degrees of freedom for each component.
g specifying the mixing proportions for each component.
g by n matrix of posterior probability of component membership.
init and known, if specified, is a list structure containing
at least one of mu, sigma, delta, dof, pro
(See dfmmst for the structure of each of these elements).
If init=FALSE (default), the program uses an automatic approach based on
k-means clustering to generate an initial value for the model parameters.
Note that this may not provide the best results.As the EM algorithm is sensitive to the starting value,
it is highly recommended to apply a wide range different initializations.
A simple strategy is implemented in fmmst.init.
Lee, S. and McLachlan, G.J. (2014) Finite mixtures of multivariate skew t-distributions: some recent and new results. Statistics and Computing, 24, 181-202.
Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for
fitting mixtures of multivariate skew t-distributions via the EM algorithm.
Journal of Statistical Software, 55(12), 1-22.
URL http://www.jstatsoft.org/v55/i12/.
fmmst.init, rfmmst, dfmmst, fmmst.contour.2d
#a short demo using AIS data
data(ais)
Fit <- fmmst(2, ais[,c(2,12)], itmax=5)
summary(Fit)
print(Fit)
Run the code above in your browser using DataLab