fmmst.init(g, dat, known=NULL, clust=NULL, nkmeans=20, tmethod=1)p or a matrix with p columns.
NULL.
nrow(dat) containing the
initial labels for each data point in dat. The default is NULL,
indicating no initial clustering is known.
20.
pmt for details.
fmmst, each containing the following parameters:
g numeric matrices containing the location parameter for each component.
g numeric matrices containing the scale parameter for each component.
g numeric matrices containing the skewness parameter for each component.
g representing the degrees of freedom for each component.
g specifying the mixing proportions for each component.
g by n matrix of initial probability of component membership.
fmmst.init() can be used,
which will return a list of objects with the same structure as initial.
An example is given in the examples section below.
The argument known, if specified, is a list structure containing
at least one of mu, sigma, delta, dof, pro
(See dfmmst for the structure of each of these elements).
Note that although not all parameters need to be provided in known,
the parameters that are provided must be fully specified.
They cannot be partially specified, e.g. only some elements or some components are specified.
Lee, S. and McLachlan, G.J. (2014) Finite mixtures of multivariate skew t-distributions: some recent and new results. Statistics and Computing, 24, 181-202.
Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for
fitting mixtures of multivariate skew t-distributions via the EM algorithm.
Journal of Statistical Software, 55(12), 1-22.
URL http://www.jstatsoft.org/v55/i12/.
rfmmst, dfmmst, fmmst.contour.2d
#a short demo using AIS data
data(ais)
Fit.init <- fmmst.init(2, ais[,c(2,12)])
#the number of available initializations
length(Fit.init)
#getting the first set of available initialization
Fit.init[[1]]
## Not run:
# Fit1 <- fmmst(2, ais[,c(2,12)], initial=Fit.init[[1]])
# Fit2 <- fmmst(2, ais[,c(2,12)], initial=Fit.init[[2]])
# ## End(Not run)
Run the code above in your browser using DataLab