Learn R Programming

EMMIXuskew (version 0.11-6)

fmmstDA: Discriminant analysis using Multivariate Skew t Mixture Models

Description

performs discriminant analysis (DA) for a specified multivariate skew t mixture distribution.

Usage

fmmstDA(g, dat, model, tmethod=1)

Arguments

g
a scalar specifying the number of components in the mixture model
dat
the data matrix giving the coordinates of the point(s) to be classified.
model
a list containing the parameters of the model, including mu, sigma, delta, dof (for fmmstDA only) and pro.
tmethod
(optional) an integer indicating which method to use when computing t distribution function values. See pmt for details.

Value

fmmstDA returns a vector of length nrow(dat) of the cluster labels

references

Lee, S. and McLachlan, G.J. (2013) EMMIXuskew: An R package for fitting mixtures of multivariate skew t-distributions via the EM algorithm. Journal of Statistical Software, 55(12), 1-22. URL http://www.jstatsoft.org/v55/i12/.

Details

For the structure of the elements of model, see dfmmst.

See Also

dfmmst, fmmst

Examples

Run this code
obj <- list()
obj$mu <- list(c(17,19), c(5,22), c(6,10))
obj$sigma <- list(diag(2), matrix(c(2,0,0,1),2), matrix(c(3,7,7,24),2))
obj$delta <- list(c(3,1.5), c(5,10), c(2,0))
obj$dof <- c(1, 2, 3)
obj$pro <- c(0.25, 0.25, 0.5)
X2 <- rfmmst(3, 50, known=obj)
fmmstDA(3, X2[,1:2], obj)

Run the code above in your browser using DataLab