fmmt(g = 1, dat, initial = NULL, known = NULL, itmax = 100, eps = 1e-03, nkmeans=20, print = T)
"summary"(object, ...)
"print"(x, ...)"fmmt", i.e. a fitted model.
p or a matrix with p columns.
NULL.
NULL.
100.
1e-6.
20.
TRUE, output for each iteration will be printed out.
if FALSE, no output is printed. The default is TRUE. See the 'Details' section.
g numeric matrices containing the location parameter for each component.
g numeric matrices containing the scale parameter for each component.
g representing the degrees of freedom for each component.
g specifying the mixing proportions for each component.
g by n matrix of posterior probability of component membership.
init and known, if specified, is a list structure containing
at least one of mu, sigma, delta, dof, pro
(See dfmmst for the structure of each of these elements).
If init=FALSE (default), the program uses an automatic approach based on
k-means clustering to generate an initial value for the model parameters.
McLachlan G.J. and Peel D. (2000). Finite Mixture Models. New York: Wiley.
rfmmst, dfmmst, fmmst.contour.2d
#a short demo using AIS data
data(ais)
Fit <- fmmt(2, ais[,c(2,12)], itmax=10)
summary(Fit)
print(Fit)
Run the code above in your browser using DataLab