delta in a multivariate skew t-mixture model.
delta.test(stmodel=NULL, tmodel=NULL, stloglik, tloglik, r)mu, sigma, delta, dof and pro.
This is usually an output from a fmmst run.
mu, sigma, dof and pro.
This is usually an output from a fmmt run.
H0: delta = 0 (for all components in the mixture model)
H1: delta different from 0 (for at least one component in the mixture)
The test statistics is LR = -2 (L1 - L2), which follows a chi-sqaured distribution with r degrees of freedom under H0. r is the difference between the number of parameters in H0 and H1. See references for further details.
R package for
fitting mixtures of multivariate skew t-distributions via the EM algorithm.
Journal of Statistical Software, 55(12), 1-22.
URL http://www.jstatsoft.org/v55/i12/.
delta.test(stloglik=-1343.541, tloglik=-1353.842, r=4)
Run the code above in your browser using DataLab